Returns a function(err) to be used as the callback argument of
Router$handle(). It is invoked when the router exhausts its stack
without sending a response, or when an unhandled occurs.
No error and no response sent -- writes a 404 Not Found HTML
response. The body message is "Cannot <METHOD> <PATH_INFO>".
Error -- derives the HTTP status from err$status (must be a
numeric 4xx or 5xx value); falls back to res$status, and then to
500. The body contains the standard HTTP phrase for the status code.
In all cases the response is an HTML document and includes the security
headers Content-Security-Policy: default-src 'none' and
X-Content-Type-Options: nosniff. Pre-existing Content-Encoding,
Content-Language, and Content-Range headers are removed.
finalHandler(req, res, options)A function(err) that sends the final HTTP response.
(environment)
Rook request environment.
(Response)
Response object.
(list)
Reserved for future use; currently ignored.